#!/bin/bash
#
# packager                          : Frederic Boulet <bipbip> bipbiponlinux~AT~gmail.com
#
# dernières révisions       : 6/12/2008
#
#package			: urbanterror
#homepage			: http://www.urbanterror.net
#source location	: http://games.mirrors.tds.net/pub/planetquake3/modifications/urbanterror/UrbanTerror_41_FULL.zip
#dependency         : sdl,openal,curl

softname='urbanterror'
softnamesrc='UrbanTerror'
softversion='4.1'
softversionsrc='41'
packageversion='54.1'

#
# ZenWalk standard: type CPUet architecture
#
# arch='i486' -> le compileur utilise seulement les instructions 80486
# cpu='i686'  -> optimisation faîte pour PII et >
#
arch='i486'
cpu='i686'

#
# destination du package
#
prefix=/usr

#
# building-computer dependent: the number of parallel 'jobs' of 'make'
#
# "gros" PC: 6 compilations à la fois
#
# numjobs='-j6'
#
# "léger" PC: 2 compilations à la fois
#
numjobs='-j2'

#
# log
#
(

#
# paramètres pour compiler
#
buildir=$(pwd)
src="$buildir/$softnamesrc"
srcpkg="$buildir/"$softnamesrc"_"$softversionsrc"_FULL.zip"
package="$softname-$softversion-$arch-$packageversion"
dest="$buildir/$package"
source=http://games.mirrors.tds.net/pub/planetquake3/modifications/urbanterror/"$softnamesrc"_"$softversionsrc"_FULL.zip

#
# preparer le répertoire qui accueillera la compilation
#
rm -rf $dest
mkdir -p $dest
mkdir -p $dest/install
mkdir -p $dest/$prefix/bin
mkdir -p $dest/usr/share/applications
mkdir -p $dest/usr/share/$softname
mkdir -p $dest/usr/share/icons/hicolor/48x48/apps
mkdir -p $dest/usr/doc
mkdir -p $dest/usr/src/$softname-$softversion

#
# mettre le slack-desc en place. 
#
cat <<EOF > $dest/install/slack-desc
           |-----handy-ruler------------------------------------------------------|
urbanterror: urbanterror - a free multiplayer first person shooter
urbanterror:
urbanterror: Urban Terror can be described as a Hollywood tactical shooter; 
urbanterror: somewhat realism based, but the motto is "fun over realism". 
urbanterror: This results in a very unique, enjoyable and addictive game.
urbanterror: 
urbanterror: 
urbanterror: 
urbanterror: 
urbanterror:
urbanterror: 
EOF

#
# Verifie si package est present
#
if [ -f  "$softnamesrc"_"$softversionsrc"_FULL.zip ]; then
	echo "Source file already here, no need to download";
else
 	echo "Downloading source"
	wget -c $source
fi

#
# extraire les sources
#
# tar.gz : tar zxvf $srcpkg
# tar.bz2: tar xjvf $srcpkg
# tgz    : tar xzvf $srcpkg
#
cd $buildir
unzip $srcpkg -d $buildir

#
# "faire" le package package
#

cd $src   

cp ioUrTded.i386 $dest/usr/share/$softname
cp ioUrbanTerror.i386 $dest/usr/share/$softname
cp -r $src/q3ut4 $dest/usr/share/$softname
    
chmod 755 $dest/usr/share/$softname/ioUrTded.i386
chmod 755 $dest/usr/share/$softname/ioUrbanTerror.i386

#
# "faire" icon
#
wget http://upload.wikimedia.org/wikipedia/en/5/56/Urbanterror.svg
convert $src/Urbanterror.svg -resize 48x48 $dest/usr/share/icons/hicolor/48x48/apps/urbanterror.png

# "faire" .desktop
cat << "EOF" > $dest/usr/share/applications/$softname.desktop
[Desktop Entry]
Name=UrbanTerror
Comment=A first person shooter
Exec=urbanterror
Icon=urbanterror
Terminal=false
Type=Application
Categories=Game;ActionGame;
Encoding=UTF-8
EOF

cat <<EOF > $dest/usr/bin/urbanterror
#!/bin/sh
exec /usr/share/urbanterror/ioUrbanTerror.i386 "\$@"
EOF

chmod 755 $dest/usr/bin/urbanterror

#
# ajout des fichiers de docs, infos, ...
#
    cd $src
    mkdir -p $dest/usr/doc/$softname-$softversion
    cp -a \
      ioUrbanTerror_id-readme.txt ioUrbanTerror_COPYING.txt ioUrbanTerror_README.txt\
      $dest/usr/doc/$softname-$softversion
      
#
# Stripper les éxécutables
# (Commenter ces lignes si besoin d'infos de débuggage)
#
( cd $dest
  find . | xargs file | grep "executable" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
  find . | xargs file | grep "shared object" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
)

#
# Mettre le zenbuild à sa place
#
cd $buildir
cp build-$softname.sh $dest/$prefix/src/$softname-$softversion

#
# fixer les permissions
#
chown -R root.root $dest

cd $dest
find . -perm 664 -exec chmod 644 {} \;
find . -perm 600 -exec chmod 644 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 400 -exec chmod 644 {} \;
find . -perm 440 -exec chmod 644 {} \;
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 511 -exec chmod 755 {} \;
find . -perm 711 -exec chmod 755 {} \;
find . -perm 555 -exec chmod 755 {} \;

#
# fabriquer le zenpackage
#
cd $dest
makepkg -l y -c n $dest.tgz

#
# produire la signature md5 du package
#
cd $buildir
md5sum $package.tgz > $package.md5

#
# fabriquer le fichier dépendance
#
echo -n "directfb,sdl,zlib" > $package.dep

#
# Fabriquer le fichier source
#
echo http://zenwalk.pinguix.com/user-accounts/bip/EXTRA/games/urbanterror/source/build-urbanterror.sh > $package.src
echo http://upload.wikimedia.org/wikipedia/en/5/56/Urbanterror.svg >> $package.src
echo $source >> $package.src

#
# supprimer source
#
rm -rf $src
rm -rf $dest

#
# log
#
) 2>&1 | tee "$softname-$softversion-build.log"
